@@ -851,7 +851,7 @@ qcMetric_EVD_Charge =  setRefClass(
       "Charge distribution per Raw file. For typtic digests, peptides of charge 2 
 (one N-terminal and one at tryptic C-terminal R or K residue) should be dominant.
 Ionization issues (voltage?), in-source fragmentation, missed cleavages and buffer irregularities can 
-cause a shift (see [Bittremieux 2017, DOI: 10.1002/mas.21544](http://onlinelibrary.wiley.com/doi/10.1002/mas.21544/abstract) ).
+cause a shift (see [Bittremieux 2017, DOI: 10.1002/mas.21544](https://onlinelibrary.wiley.com/doi/abs/10.1002/mas.21544) ).
 The charge distribution should be similar across Raw files.
 Consistent charge distribution is paramount for comparable 3D-peak intensities across samples.
 
@@ -892,7 +892,7 @@ qcMetric_EVD_IDoverRT =  setRefClass(
 Ideally, the LC gradient is chosen such that the number of identifications (here, after FDR filtering) is 
 uniform over time, to ensure consistent instrument duty cycles. Sharp peaks and uneven distribution of 
 identifications over time indicate potential for LC gradient optimization. 
-See [Moruz 2014, DOI: 10.1002/pmic.201400036](http://www.ncbi.nlm.nih.gov/pubmed/24700534) for details.
+See [Moruz 2014, DOI: 10.1002/pmic.201400036](https://pubmed.ncbi.nlm.nih.gov/24700534/) for details.
 
 Heatmap score [EVD: ID rate over RT]: Scored using 'Uniform' scoring function, i.e. constant receives good score, extreme shapes are bad.
 ",
